@@ -13,12 +13,28 @@
 
 namespace Views {
 
+  class DataEntry
+  {
+  public:
+    ::Base::DataPtr data;
+
+  public:
+    DataEntry(::Base::DataPtr data)
+    : data(data)
+    {
+      // no code
+    }
+  };
+
+  typedef Lum::Model::StdTable<DataEntry*>     DataEntryModel;
+  typedef Lum::Base::Reference<DataEntryModel> DataEntryModelRef;
+
   class Search : public ::Base::View
   {
   private:
     Lum::Model::ActionRef    viewAction;
     Lum::Model::ActionRef    searchAction;
-    Lum::Model::ListTableRef model;
+    DataEntryModelRef        model;
     Lum::Model::StringRef    searchValue;
     Lum::Table               *table;
     Lum::Panel               *top;
